@@ -5,9 +5,6 @@ saltfactories.factories.master
 
 Master Factory
 """
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
 
 try:
     import salt.config
