@@ -5,10 +5,6 @@ saltfactories.utils.compat
 
 Imports compatability layer
 """
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import sys
 import weakref
 
