@@ -17,12 +17,12 @@ log = logging.getLogger(__name__)
 
 
 @contextmanager
-def log_server_listener(log_server_port):
-    def stop(port):
+def log_server_listener(log_server_host, log_server_port):
+    def stop(host, port):
         log.debug("Stopping the multiprocessing logging queue listener")
         context = zmq.Context()
         sender = context.socket(zmq.PUSH)
-        sender.connect("tcp://127.0.0.1:{}".format(port))
+        sender.connect("tcp://{}:{}".format(host, port))
         try:
             sender.send(msgpack.dumps(None))
             log.info("Sent sentinel to trigger log server shutdown")
@@ -31,11 +31,11 @@ def log_server_listener(log_server_port):
             context.term()
         log.debug("Stopped the multiprocessing logging queue listener")
 
-    def process_logs(port):
+    def process_logs(host, port):
         context = zmq.Context()
         puller = context.socket(zmq.PULL)
         try:
-            puller.bind("tcp://127.0.0.1:{}".format(port))
+            puller.bind("tcp://{}:{}".format(host, port))
         except zmq.ZMQError as exc:
             log.exception("Unable to bind to puller port: %s", port)
             return
@@ -68,11 +68,13 @@ def log_server_listener(log_server_port):
             puller.close(1)
             context.term()
 
-    process_queue_thread = threading.Thread(target=process_logs, args=(log_server_port,))
+    process_queue_thread = threading.Thread(
+        target=process_logs, args=(log_server_host, log_server_port)
+    )
     process_queue_thread.start()
 
     yield
 
-    stop(log_server_port)
+    stop(log_server_host, log_server_port)
     log.info("Joining the logging server process thread")
     process_queue_thread.join()
