@@ -6,10 +6,6 @@
     Functional tests for the salt syndic factory
 """
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import re
 
 import pytest
